==> haskell-authenticate-1.3.5.2-117-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-CqN54atzlF5Ll2VvVi8x8n
key:                  authenticate-1.3.5.2-CqN54atzlF5Ll2VvVi8x8n
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  2ab4af14dc9a41af27a2ecfc084c1f62
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-CqN54atzlF5Ll2VvVi8x8n
depends:
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-aeson-2.1.0.0-AE284sPyAF3JXisbeAipws base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    conduit-1.3.6.1-LEKlJ5sjhOMOY4BoQvHAk containers-0.6.7
    html-conduit-1.3.2.2-C1s8PELH66B8oXoAxfJ0dm
    http-conduit-2.3.9.1-6kcitIgkYMzASPRujG35V6
    http-types-0.12.4-3waRWhsRr1C4PfAAAPJbwc
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    xml-conduit-1.9.1.4-H1IDoMUbIU5KkVXM4r4KJI

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-1.3.5.2-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-authenticate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 authenticate
version:              1.3.5.2
visibility:           public
id:                   authenticate-1.3.5.2-LhDshSBOtYD6xMkmKzEHrh
key:                  authenticate-1.3.5.2-LhDshSBOtYD6xMkmKzEHrh
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman, Hiromi Ishii, Arash Rouhani
stability:            Stable
homepage:             http://github.com/yesodweb/authenticate
synopsis:             Authentication methods for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate>.

category:             Web
abi:                  89b32484b1ede40939d5c513b51be3e5
exposed:              True
exposed-modules:
    Web.Authenticate.BrowserId Web.Authenticate.OpenId
    Web.Authenticate.OpenId.Providers Web.Authenticate.Rpxnow

hidden-modules:
    Web.Authenticate.Internal OpenId2.Discovery OpenId2.Normalization
    OpenId2.Types OpenId2.XRDS

import-dirs:          /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/authenticate-1.3.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-authenticate
hs-libraries:         HSauthenticate-1.3.5.2-LhDshSBOtYD6xMkmKzEHrh
depends:
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-aeson-2.1.0.0-65ranVjaulLHxYn97FSumS base-4.17.2.1
    blaze-builder-0.4.2.3-1WUo1omsOYUH2PSkelI6MS bytestring-0.11.5.3
    case-insensitive-1.2.1.0-FZkso54i68UDZy9QWLkbnV
    conduit-1.3.6.1-GHyJy0fEO4I5Y3sMB26bfT containers-0.6.7
    html-conduit-1.3.2.2-ClxKtqpbEFC5P1cBVXgLwS
    http-conduit-2.3.9.1-G9skUe0R0eKFLtgtZaUIye
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    network-uri-2.6.4.2-APaQU0Ye6OaKm6pWDY2rCG
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    xml-conduit-1.9.1.4-HqI64ofa1BLBo89Vn03fsg

haddock-interfaces:
    /usr/share/doc/haskell-authenticate/html/authenticate.haddock

haddock-html:         /usr/share/doc/haskell-authenticate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
